synthetic\_aia\_mia.aia package
===============================

Submodules
----------

synthetic\_aia\_mia.aia.soft module
-----------------------------------

.. automodule:: synthetic_aia_mia.aia.soft
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: synthetic_aia_mia.aia
   :members:
   :undoc-members:
   :show-inheritance:
